@@ -25,14 +25,13 @@ class CreateApplicationRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'CreateApplication','ens')
 		self.set_method('POST')
 
-	def get_Template(self):
+	def get_Template(self): # String
 		return self.get_query_params().get('Template')
 
-	def set_Template(self,Template):
-		self.add_query_param('Template',Template)
-
-	def get_Timeout(self):
+	def set_Template(self, Template):  # String
+		self.add_query_param('Template', Template)
+	def get_Timeout(self): # Integer
 		return self.get_query_params().get('Timeout')
 
-	def set_Timeout(self,Timeout):
-		self.add_query_param('Timeout',Timeout)
\ No newline at end of file
+	def set_Timeout(self, Timeout):  # Integer
+		self.add_query_param('Timeout', Timeout)
