@@ -25,6 +25,11 @@ class CreateImageRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'CreateImage','ens')
 		self.set_method('POST')
 
+	def get_SnapshotId(self): # String
+		return self.get_query_params().get('SnapshotId')
+
+	def set_SnapshotId(self, SnapshotId):  # String
+		self.add_query_param('SnapshotId', SnapshotId)
 	def get_DeleteAfterImageUpload(self): # String
 		return self.get_query_params().get('DeleteAfterImageUpload')
 
@@ -35,11 +40,6 @@ class CreateImageRequest(RpcRequest):
 
 	def set_ImageName(self, ImageName):  # String
 		self.add_query_param('ImageName', ImageName)
-	def get_product(self): # String
-		return self.get_query_params().get('product')
-
-	def set_product(self, product):  # String
-		self.add_query_param('product', product)
 	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
