@@ -25,14 +25,13 @@ class CreateSecurityGroupRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'CreateSecurityGroup','ens')
 		self.set_method('POST')
 
-	def get_SecurityGroupName(self):
+	def get_Description(self): # String
+		return self.get_query_params().get('Description')
+
+	def set_Description(self, Description):  # String
+		self.add_query_param('Description', Description)
+	def get_SecurityGroupName(self): # String
 		return self.get_query_params().get('SecurityGroupName')
 
-	def set_SecurityGroupName(self,SecurityGroupName):
-		self.add_query_param('SecurityGroupName',SecurityGroupName)
-
-	def get_Version(self):
-		return self.get_query_params().get('Version')
-
-	def set_Version(self,Version):
-		self.add_query_param('Version',Version)
\ No newline at end of file
+	def set_SecurityGroupName(self, SecurityGroupName):  # String
+		self.add_query_param('SecurityGroupName', SecurityGroupName)
