@@ -25,20 +25,13 @@ class DescribeEnsNetDistrictRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'DescribeEnsNetDistrict','ens')
 		self.set_method('POST')
 
-	def get_NetLevelCode(self):
+	def get_NetLevelCode(self): # String
 		return self.get_query_params().get('NetLevelCode')
 
-	def set_NetLevelCode(self,NetLevelCode):
-		self.add_query_param('NetLevelCode',NetLevelCode)
-
-	def get_NetDistrictCode(self):
+	def set_NetLevelCode(self, NetLevelCode):  # String
+		self.add_query_param('NetLevelCode', NetLevelCode)
+	def get_NetDistrictCode(self): # String
 		return self.get_query_params().get('NetDistrictCode')
 
-	def set_NetDistrictCode(self,NetDistrictCode):
-		self.add_query_param('NetDistrictCode',NetDistrictCode)
-
-	def get_Version(self):
-		return self.get_query_params().get('Version')
-
-	def set_Version(self,Version):
-		self.add_query_param('Version',Version)
\ No newline at end of file
+	def set_NetDistrictCode(self, NetDistrictCode):  # String
+		self.add_query_param('NetDistrictCode', NetDistrictCode)
