@@ -25,20 +25,18 @@ class DescribeServcieScheduleRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'DescribeServcieSchedule','ens')
 		self.set_method('POST')
 
-	def get_Uuid(self):
+	def get_Uuid(self): # String
 		return self.get_query_params().get('Uuid')
 
-	def set_Uuid(self,Uuid):
-		self.add_query_param('Uuid',Uuid)
-
-	def get_PodConfigName(self):
+	def set_Uuid(self, Uuid):  # String
+		self.add_query_param('Uuid', Uuid)
+	def get_PodConfigName(self): # String
 		return self.get_query_params().get('PodConfigName')
 
-	def set_PodConfigName(self,PodConfigName):
-		self.add_query_param('PodConfigName',PodConfigName)
-
-	def get_AppId(self):
+	def set_PodConfigName(self, PodConfigName):  # String
+		self.add_query_param('PodConfigName', PodConfigName)
+	def get_AppId(self): # String
 		return self.get_query_params().get('AppId')
 
-	def set_AppId(self,AppId):
-		self.add_query_param('AppId',AppId)
\ No newline at end of file
+	def set_AppId(self, AppId):  # String
+		self.add_query_param('AppId', AppId)
