@@ -25,14 +25,13 @@ class JoinPublicIpsToEpnInstanceRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'JoinPublicIpsToEpnInstance','ens')
 		self.set_method('POST')
 
-	def get_EPNInstanceId(self):
+	def get_EPNInstanceId(self): # String
 		return self.get_query_params().get('EPNInstanceId')
 
-	def set_EPNInstanceId(self,EPNInstanceId):
-		self.add_query_param('EPNInstanceId',EPNInstanceId)
-
-	def get_InstanceInfos(self):
+	def set_EPNInstanceId(self, EPNInstanceId):  # String
+		self.add_query_param('EPNInstanceId', EPNInstanceId)
+	def get_InstanceInfos(self): # String
 		return self.get_query_params().get('InstanceInfos')
 
-	def set_InstanceInfos(self,InstanceInfos):
-		self.add_query_param('InstanceInfos',InstanceInfos)
\ No newline at end of file
+	def set_InstanceInfos(self, InstanceInfos):  # String
+		self.add_query_param('InstanceInfos', InstanceInfos)
