@@ -25,14 +25,13 @@ class JoinVSwitchesToEpnInstanceRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'JoinVSwitchesToEpnInstance','ens')
 		self.set_method('POST')
 
-	def get_VSwitchesInfo(self):
+	def get_VSwitchesInfo(self): # String
 		return self.get_query_params().get('VSwitchesInfo')
 
-	def set_VSwitchesInfo(self,VSwitchesInfo):
-		self.add_query_param('VSwitchesInfo',VSwitchesInfo)
-
-	def get_EPNInstanceId(self):
+	def set_VSwitchesInfo(self, VSwitchesInfo):  # String
+		self.add_query_param('VSwitchesInfo', VSwitchesInfo)
+	def get_EPNInstanceId(self): # String
 		return self.get_query_params().get('EPNInstanceId')
 
-	def set_EPNInstanceId(self,EPNInstanceId):
-		self.add_query_param('EPNInstanceId',EPNInstanceId)
\ No newline at end of file
+	def set_EPNInstanceId(self, EPNInstanceId):  # String
+		self.add_query_param('EPNInstanceId', EPNInstanceId)
