@@ -25,11 +25,21 @@ class ModifyInstanceAttributeRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'ModifyInstanceAttribute','ens')
 		self.set_method('POST')
 
+	def get_UserData(self): # String
+		return self.get_query_params().get('UserData')
+
+	def set_UserData(self, UserData):  # String
+		self.add_query_param('UserData', UserData)
 	def get_Password(self): # String
 		return self.get_query_params().get('Password')
 
 	def set_Password(self, Password):  # String
 		self.add_query_param('Password', Password)
+	def get_HostName(self): # String
+		return self.get_query_params().get('HostName')
+
+	def set_HostName(self, HostName):  # String
+		self.add_query_param('HostName', HostName)
 	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
