@@ -25,20 +25,13 @@ class RebootInstanceRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'RebootInstance','ens')
 		self.set_method('POST')
 
-	def get_ForceStop(self):
+	def get_ForceStop(self): # String
 		return self.get_query_params().get('ForceStop')
 
-	def set_ForceStop(self,ForceStop):
-		self.add_query_param('ForceStop',ForceStop)
-
-	def get_Version(self):
-		return self.get_query_params().get('Version')
-
-	def set_Version(self,Version):
-		self.add_query_param('Version',Version)
-
-	def get_InstanceId(self):
+	def set_ForceStop(self, ForceStop):  # String
+		self.add_query_param('ForceStop', ForceStop)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
